from .base_enum import BaseEnum


class Difficulty(BaseEnum):
    EASY = "Easy"
    NORMAL = "Normal"
    HARD = "Hard"
    EXPERT = "Expert"
    EXPERT_PLUS = "ExpertPlus"
    UNKNOWN = "Unknown"
